summaryrefslogtreecommitdiff
path: root/remote.h
diff options
context:
space:
mode:
authorKlaus Schmidinger <vdr@tvdr.de>2006-10-14 11:09:01 +0200
committerKlaus Schmidinger <vdr@tvdr.de>2006-10-14 11:09:01 +0200
commitf2c619568fbd6a1c62fd0d0ee9c2a0f1c5702860 (patch)
tree796b3a7e1b5779857f9eeeac6d29b834678b673b /remote.h
parent3a9deab56cf59a7620cf6e46411bcb4dd3e79f87 (diff)
downloadvdr-f2c619568fbd6a1c62fd0d0ee9c2a0f1c5702860.tar.gz
vdr-f2c619568fbd6a1c62fd0d0ee9c2a0f1c5702860.tar.bz2
Fixed handling plugins from cRemote::PutMacro() and cRemote::CallPlugin()
Diffstat (limited to 'remote.h')
-rw-r--r--remote.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/remote.h b/remote.h
index 3a2bb749..e5b80b2c 100644
--- a/remote.h
+++ b/remote.h
@@ -4,7 +4,7 @@
* See the main source file 'vdr.c' for copyright information and
* how to reach the author.
*
- * $Id: remote.h 1.35 2006/04/17 08:59:48 kls Exp $
+ * $Id: remote.h 1.36 2006/10/14 10:56:50 kls Exp $
*/
#ifndef __REMOTE_H
@@ -28,7 +28,8 @@ private:
static char *unknownCode;
static cMutex mutex;
static cCondVar keyPressed;
- static const char *plugin;
+ static const char *keyMacroPlugin;
+ static const char *callPlugin;
char *name;
protected:
cRemote(const char *Name);
@@ -56,7 +57,7 @@ public:
///< false will be returned and the caller should try again later.
static const char *GetPlugin(void);
///< Returns the name of the plugin that was set with a previous
///< call to CallPlugin(). The internally stored pointer to the
///< plugin name will be reset to NULL by this call.
static bool HasKeys(void);
static eKeys Get(int WaitMs = 1000, char **UnknownCode = NULL);
@@ -56,7 +57,7 @@ public:
static const char *GetPlugin(void);
///< Returns the name of the plugin that was set with a previous
- ///< call to CallPlugin(). The internally stored pointer to the
+ ///< call to PutMacro() or CallPlugin(). The internally stored pointer to the
///< plugin name will be reset to NULL by this call.
static bool HasKeys(void);